@@ -4,6 +4,14 @@ use base 'Catalyst::Controller';
 
 __PACKAGE__->config->{namespace} = '';
 
+=head1 NAME
+
+MojoMojo::Controller::Root
+
+=head1 ACTIONS
+
+=over 4
+
 =item begin (builtin)
 
 =cut
@@ -39,12 +47,30 @@ sub default : Path {
     $c->stash->{template} = 'message.tt';
 }
 
+=item set_lang
+
+(Re)set language of current session.
+
+=cut
+
 sub set_lang :Global {
     my ($self,$c) = @_;
     $c->session->{lang}=$c->req->params->{lang};
     $c->res->redirect($c->req->params->{redir});
 }
 
+=item render
+
+Finally use ActionClass RenderView to render the content.
+
+=cut
+
+sub render : ActionClass('RenderView') {
+    my ($self) = shift;
+    my ($c)    = @_;
+    $c->stash->{path} ||= '/';
+}
+
 =item end (builtin)
 
 At the end of any request, forward to view unless there is a template
@@ -53,12 +79,6 @@ show a debug screen.
 
 =cut
 
-sub render : ActionClass('RenderView') {
-    my ($self) = shift;
-    my ($c)    = @_;
-    $c->stash->{path} ||= '/';
-}
-
 sub end : Private {
     my ( $self, $c ) = @_;
     $c->req->uri->path( $c->stash->{pre_hacked_uri}->path )
@@ -94,4 +114,13 @@ sub auto : Private {
     $c->stash->{template} = 'user/validate.tt';
 }
 
+=back
+
+=head1 LICENSE
+
+This library is free software . You can redistribute it and/or modify 
+it under the same terms as perl itself.
+
+=cut
+
 1;
