@@ -14,8 +14,6 @@ unless ($@) {
     );
 }
 
-sub primary_formatter { 1; }
-
 =head1 NAME
 
 MojoMojo::Formatter::MarkDown - Texile formatting for your content
@@ -29,6 +27,14 @@ syntax for writing human-friendly formatted text.
 
 =over 4
 
+=item primary_formatter
+
+See also L<MojoMojo::Formatter/primary_formatter>.
+
+=cut
+
+sub primary_formatter { 1; }
+
 =item format_content_order
 
 Format order can be 1-99. The Markdown formatter runs on 15
