@@ -16,7 +16,6 @@ my $textile = Text::Textile2->new(
 __PACKAGE__->load_components(qw/DateTime::Epoch PK::Auto UTF8Columns Core/);
 __PACKAGE__->table("comment");
 __PACKAGE__->add_columns(
-    "id",
     "id",
     { data_type => "INTEGER", is_nullable => 0, size => undef, is_auto_increment => 1 },
     "poster",
@@ -36,6 +35,14 @@ __PACKAGE__->belongs_to( "page",    "Page",   { id => "page" } );
 __PACKAGE__->belongs_to( "picture", "Photo",  { id => "picture" } );
 __PACKAGE__->utf8_columns(qw/body/);
 
+=head1 NAME
+
+MojoMojo::Schema::Result::Comment
+
+=head1 METHODS
+
+=over 4
+
 =item formatted
 
 Returns a textile formatted version of the given comment.
