@@ -19,5 +19,16 @@ __PACKAGE__->set_primary_key("id");
 __PACKAGE__->belongs_to( "from_page", "Page", { id => "from_page" } );
 __PACKAGE__->belongs_to( "to_page",   "Page", { id => "to_page" } );
 
+=head1 NAME
+
+MojoMojo::Schema::Result::Link
+
+=head1 LICENSE
+
+This library is free software . You can redistribute it and/or modify 
+it under the same terms as perl itself.
+
+=cut
+
 1;
 
