@@ -66,6 +66,20 @@ __PACKAGE__->has_many( "page_versions", "PageVersion", { "foreign.creator" => "s
 __PACKAGE__->many_to_many( roles => 'role_members', 'role' );
 __PACKAGE__->has_many( "contents", "Content", { "foreign.creator" => "self.id" } );
 
+=head1 NAME
+
+MojoMojo::Schema::Result::Person
+
+=head1 METHODS
+
+=over 4
+
+=item is_admin
+
+Checks if user belongs to list of admins.
+
+=cut
+
 sub is_admin {
     my $self   = shift;
     my $admins = MojoMojo->pref('admins');
@@ -74,6 +88,12 @@ sub is_admin {
     return 0;
 }
 
+=item link
+
+Returns relative link to users home node.
+
+=cut
+
 sub link {
     my ($self) = @_;
     return lc "/" . ( $self->login || MojoMojo->pref('anonymous_user') );
@@ -148,6 +168,12 @@ sub interests_formatted { $textile->process(shift->interests); }
 sub music_formatted { $textile->process(shift->music); }
 sub movies_formatted { $textile->process(shift->movies); }
 
+=item age
+
+Returns age of the user in years.
+
+=cut
+
 sub age {
     my ($self) = @_;
     if (my $birthdate = $self->born) {
@@ -156,4 +182,13 @@ sub age {
     }
 }
 
+=back
+
+=head1 LICENSE
+
+This library is free software . You can redistribute it and/or modify 
+it under the same terms as perl itself.
+
+=cut
+
 1;
\ No newline at end of file
