@@ -16,4 +16,15 @@ __PACKAGE__->set_primary_key( "page", "role", "privilege" );
 __PACKAGE__->belongs_to( "page", "Page", { id => "page" } );
 __PACKAGE__->belongs_to( "role", "Role", { id => "role" } );
 
+=head1 NAME
+
+MojoMojo::Schema::Result::RolePrivilege
+
+=head1 LICENSE
+
+This library is free software . You can redistribute it and/or modify 
+it under the same terms as perl itself.
+
+=cut
+
 1;
