@@ -25,10 +25,34 @@ __PACKAGE__->belongs_to( "person", "Person", { id => "person" } );
 __PACKAGE__->belongs_to( "page",   "Page",   { id => "page" } );
 __PACKAGE__->belongs_to( "photo",  "Photo",  { id => "photo" } );
 
+=head1 NAME
+
+MojoMojo::Schema::Result::Tag
+
+=head1 METHODS
+
+=over 4
+
+=item refcount
+
+Convenience method to return get_column('refcount') if this column
+is available.
+
+=cut
+
 sub refcount {
     my $self = shift;
     return $self->get_column('refcount') if $self->has_column_loaded('refcount');
     croak 'Tried to call refcount on resultset without column';
 }
 
+=back
+
+=head1 LICENSE
+
+This library is free software . You can redistribute it and/or modify 
+it under the same terms as perl itself.
+
+=cut
+
 1;
