@@ -5,10 +5,11 @@ use base 'Catalyst::View::TT';
 use Template::Constants qw( :debug );
 
 #__PACKAGE__->config->{DEBUG}       = DEBUG_UNDEF;
-__PACKAGE__->config->{PRE_CHOMP}  = 2;
-__PACKAGE__->config->{POST_CHOMP} = 2;
-__PACKAGE__->config->{CONTEXT}    = undef;
-__PACKAGE__->config( TEMPLATE_EXTENSION => '.tt' );
+__PACKAGE__->config->{PRE_CHOMP}          = 2;
+__PACKAGE__->config->{POST_CHOMP}         = 2;
+__PACKAGE__->config->{CONTEXT}            = undef;
+__PACKAGE__->config->{TEMPLATE_EXTENSION} = '.tt';
+__PACKAGE__->config->{PRE_PROCESS}        = 'global.tt';
 
 1;
 
